using System;

// Базов клас за фигура
public abstract class Shape
{
    // Абстрактен метод за изчисление на площта
    public abstract double CalculateArea();
}

// Клас за кръг
public class Circle : Shape
{
    private double radius;

    public Circle(double radius)
    {
        this.radius = radius;
    }

    // Предефиниране на метода за изчисление на площта за кръга
    public override double CalculateArea()
    {
        return Math.PI * radius * radius;
    }
}

// Клас за правоъгълник
public class Rectangle : Shape
{
    private double length;
    private double width;

    public Rectangle(double length, double width)
    {
        this.length = length;
        this.width = width;
    }

    // Предефиниране на метода за изчисление на площта за правоъгълника
    public override double CalculateArea()
    {
        return length * width;
    }
}

// Клас за триъгълник
public class Triangle : Shape
{
    private double sideA;
    private double sideB;
    private double sideC;

    public Triangle(double sideA, double sideB, double sideC)
    {
        this.sideA = sideA;
        this.sideB = sideB;
        this.sideC = sideC;
    }

    // Предефиниране на метода за изчисление на площта за триъгълника
    public override double CalculateArea()
    {
        double p = (sideA + sideB + sideC) / 2;
        return Math.Sqrt(p * (p - sideA) * (p - sideB) * (p - sideC));
    }
}

class Program
{
    static void Main()
    {
        Circle circle = new Circle(5);
        Rectangle rectangle = new Rectangle(4, 6);
        Triangle triangle = new Triangle(3, 4, 5);

        Console.WriteLine("Circle Area: " + circle.CalculateArea());
        Console.WriteLine("Rectangle Area: " + rectangle.CalculateArea());
        Console.WriteLine("Triangle Area: " + triangle.CalculateArea());
    }
}


