using System;
using System.Collections.Generic;

class Asset
{
    public int AssetId { get; set; }
    public string Name { get; set; }
    public double InitialCost { get; set; }
    public double ResidualValue { get; set; }
    public int UsefulLife { get; set; }
}

class DepreciationCalculator
{
    private List<Asset> assets;

    public DepreciationCalculator()
    {
        assets = new List<Asset>();
    }

    public void AddAsset(Asset asset)
    {
        assets.Add(asset);
    }

    public void CalculateDepreciation()
    {
        foreach (var asset in assets)
        {
            double depreciationAmount = (asset.InitialCost - asset.ResidualValue) / asset.UsefulLife;
            double accumulatedDepreciation = 0;

            Console.WriteLine($"AssetID: {asset.AssetId}, Name: {asset.Name}, Initial Cost: {asset.InitialCost:C2}, " +
                $"Residual Value: {asset.ResidualValue:C2}, Useful Life: {asset.UsefulLife}");

            Console.WriteLine($"Depreciation: {depreciationAmount:C2} per year");

            for (int year = 1; year <= asset.UsefulLife; year++)
            {
                accumulatedDepreciation += depreciationAmount;
                Console.WriteLine($"Year {year}: Accumulated Depreciation: {accumulatedDepreciation:C2}");
            }

            Console.WriteLine();
        }
    }
}

class Program
{
    static void Main()
    {
        DepreciationCalculator calculator = new DepreciationCalculator();

        Console.Write("Enter the number of assets: ");
        int n = int.Parse(Console.ReadLine());

        for (int i = 0; i < n; i++)
        {
            Console.WriteLine($"Enter information for asset {i + 1}:");
            string[] input = Console.ReadLine().Split(" ");
            Asset asset = new Asset();
            asset.AssetId = int.Parse(input[0]);
            asset.Name = input[1];
            asset.InitialCost = double.Parse(input[2]);
            asset.ResidualValue = double.Parse(input[3]);
            asset.UsefulLife = int.Parse(input[4]);

            calculator.AddAsset(asset);
        }

        calculator.CalculateDepreciation();
    }
}


