import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;

public class DepreciationManagement {

    public static void main(String[] args) {
        Scanner scanner = new Scanner(System.in);

        // Четене на броя на дълготрайните активи
        System.out.print("Enter the number of assets: ");
        int n = Integer.parseInt(scanner.nextLine());

        // Създаване на инстанция на DepreciationCalculator
        DepreciationCalculator depreciationCalculator = new DepreciationCalculator();

        // Четене на информацията за активите и добавяне към DepreciationCalculator
        for (int i = 0; i < n; i++) {
            System.out.println("Enter information for asset " + (i + 1) + ":");
            String[] assetInfo = scanner.nextLine().split(" ");
            int assetId = Integer.parseInt(assetInfo[0]);
            String name = assetInfo[1];
            double initialCost = Double.parseDouble(assetInfo[2]);
            double residualValue = Double.parseDouble(assetInfo[3]);
            int usefulLife = Integer.parseInt(assetInfo[4]);

            Asset asset = new Asset(assetId, name, initialCost, residualValue, usefulLife);
            depreciationCalculator.addAsset(asset);
        }

        // Изчисляване на амортизацията и извеждане на информацията
        depreciationCalculator.calculateDepreciation();
        depreciationCalculator.displayDepreciationInfo();
    }
}

class Asset {
    private int assetId;
    private String name;
    private double initialCost;
    private double residualValue;
    private int usefulLife;
    private double annualDepreciation;
    private double accumulatedDepreciation;

    public Asset(int assetId, String name, double initialCost, double residualValue, int usefulLife) {
        this.assetId = assetId;
        this.name = name;
        this.initialCost = initialCost;
        this.residualValue = residualValue;
        this.usefulLife = usefulLife;
    }

    public double getAnnualDepreciation() {
        return annualDepreciation;
    }

    public void setAnnualDepreciation(double annualDepreciation) {
        this.annualDepreciation = annualDepreciation;
    }

    public double getAccumulatedDepreciation() {
        return accumulatedDepreciation;
    }

    public void setAccumulatedDepreciation(double accumulatedDepreciation) {
        this.accumulatedDepreciation = accumulatedDepreciation;
    }

    public int getAssetId() {
        return assetId;
    }

    public String getName() {
        return name;
    }

    public double getInitialCost() {
        return initialCost;
    }

    public double getResidualValue() {
        return residualValue;
    }

    public int getUsefulLife() {
        return usefulLife;
    }
}

class DepreciationCalculator {
    private List<Asset> assets;

    public DepreciationCalculator() {
        assets = new ArrayList<>();
    }

    public void addAsset(Asset asset) {
        assets.add(asset);
    }

    public void calculateDepreciation() {
        for (Asset asset : assets) {
            double annualDepreciation = (asset.getInitialCost() - asset.getResidualValue()) / asset.getUsefulLife();
            asset.setAnnualDepreciation(annualDepreciation);

            double accumulatedDepreciation = 0;
            System.out.println("AssetID: " + asset.getAssetId() +
                    ", Name: " + asset.getName() +
                    ", Initial Cost: ?" + String.format("%.2f", asset.getInitialCost()) +
                    ", Residual Value: ?" + String.format("%.2f", asset.getResidualValue()) +
                    ", Useful Life: " + asset.getUsefulLife());

            for (int year = 1; year <= asset.getUsefulLife(); year++) {
                accumulatedDepreciation += annualDepreciation;
                System.out.println("Year " + year + ": Accumulated Depreciation: ?"
                        + String.format("%.2f", accumulatedDepreciation));
            }

            asset.setAccumulatedDepreciation(accumulatedDepreciation);
        }
    }

    public void displayDepreciationInfo() {
        for (Asset asset : assets) {
            System.out.println("Depreciation: ?" + String.format("%.2f", asset.getAnnualDepreciation()) + " per year");
            System.out.println();
        }
    }
}
